# Profiling of task executions (In development)

In order to get better insight into bottlenecks and consumptions of computing
resources we are currently working on an advice, which will automatically gather
metrics about things like cpu utilisation, memory consumption and runtime statistics
for each task. This should allow identifying optimization potential in workflows and
help to reduce the cost and energy consumption of large workflows.

This feature is currently in development and will be released in December 2021.
